@@ -1,5 +1,5 @@
 package SVG::Estimate::Polyline;
-$SVG::Estimate::Polyline::VERSION = '1.0116';
+$SVG::Estimate::Polyline::VERSION = '1.02';
 use Moo;
 use Clone qw/clone/;
 use List::Util qw/pairs/;
@@ -13,7 +13,7 @@ SVG::Estimate::Polyline - Handles estimating multi-part lines.
 
 =head1 VERSION
 
-version 1.0116
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -136,6 +136,8 @@ sub BUILDARGS {
 
 sub _get_pairs {
     my ($class, $string) = @_;
+    $string =~ s/^\s+//;
+    $string =~ s/\s+$//;
     my @points = split $split_re, $string;
     my @pairs = pairs @points;
     return @pairs;
